@@ -302,9 +302,9 @@ def _get_type_list(name: str, value: any, separator: str) -> list or None:
         return None
     if isinstance(value, str):
         return value.split(separator)
-    elif isinstance(value, dict):
+    elif not isinstance(value, list):
         _val_error_unexpected_type(name, value, KEYWORD_TYPE_LIST)
-    return [value]
+    return value
 
 
 def _get_type_dict(name: str, value: any) -> list or None:
@@ -366,9 +366,10 @@ def _check_item_list_schema(name: str, plist: list, item_schema: dict):
     if item_schema is not None:
         schema_validator = SchemaValidator(item_schema)
         for pitem in plist:
-            message = schema_validator.validate('item list', pitem)
-            if message is not None:
-                raise SchemaValidationFailure(lang.VAL_ERROR_LIST_ITEM_HAS_INVALID_ELEMENT, {KEYWORD_NAME: name, 'message': message})
+            try:
+                schema_validator.validate('item list', pitem)
+            except SchemaValidationFailure as ex:
+                raise SchemaValidationFailure(lang.VAL_ERROR_LIST_ITEM_HAS_INVALID_ELEMENT, {KEYWORD_NAME: name, 'message': ex.get_message()})
 
 
 def _check_whitelist(name: str, value: any, whitelist: list, icase: bool = True):
